pub struct StreamJoinLeaveCallRequest {
pub subscription_id: String,
pub stream_name: String,
pub group_id: String,
pub id: Option<String>,
pub context: Option<Value>,
}Fields
subscription_id: Stringstream_name: Stringgroup_id: Stringid: Option<String>context: Option<Value>Trait Implementations
Sourceimpl Clone for StreamJoinLeaveCallRequest
impl Clone for StreamJoinLeaveCallRequest
Sourcefn clone(&self) -> StreamJoinLeaveCallRequest
fn clone(&self) -> StreamJoinLeaveCallRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamJoinLeaveCallRequest
impl Debug for StreamJoinLeaveCallRequest
Sourceimpl<'de> Deserialize<'de> for StreamJoinLeaveCallRequest
impl<'de> Deserialize<'de> for StreamJoinLeaveCallRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StreamJoinLeaveCallRequest
impl JsonSchema for StreamJoinLeaveCallRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StreamJoinLeaveCallRequest
impl RefUnwindSafe for StreamJoinLeaveCallRequest
impl Send for StreamJoinLeaveCallRequest
impl Sync for StreamJoinLeaveCallRequest
impl Unpin for StreamJoinLeaveCallRequest
impl UnsafeUnpin for StreamJoinLeaveCallRequest
impl UnwindSafe for StreamJoinLeaveCallRequest