pub struct InvocationError {
pub code: String,
pub message: String,
pub function_id: Option<String>,
pub stacktrace: Option<String>,
}Expand description
Structured invocation failure, mirroring the Node and Python InvocationError.
Produced from the Error::Remote variant via Error::invocation_error.
function_id is None from that accessor because the wire Remote payload
does not carry it.
Fields
code: Stringmessage: Stringfunction_id: Option<String>stacktrace: Option<String>Trait Implementations
Sourceimpl Clone for InvocationError
impl Clone for InvocationError
Sourcefn clone(&self) -> InvocationError
fn clone(&self) -> InvocationError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvocationError
impl Debug for InvocationError
Sourceimpl<'de> Deserialize<'de> for InvocationError
impl<'de> Deserialize<'de> for InvocationError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InvocationError
impl Display for InvocationError
impl Eq for InvocationError
Sourceimpl Error for InvocationError
impl Error for InvocationError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl JsonSchema for InvocationError
impl JsonSchema for InvocationError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InvocationError
impl PartialEq for InvocationError
Sourceimpl Serialize for InvocationError
impl Serialize for InvocationError
impl StructuralPartialEq for InvocationError