TriggerTypeRef

Struct TriggerTypeRef 

pub struct TriggerTypeRef<C = Value, R = Value> { /* private fields */ }
Typed handle returned by III::register_trigger_type.

Type parameters:

Implementations

Source

impl<C: Serialize, R> TriggerTypeRef<C, R>

pub fn register_trigger( &self, function_id: impl Into<String>, config: C, ) -> Result<Trigger, IIIError>

Register a trigger with compile-time validated trigger config.

pub fn register_trigger_with_metadata( &self, function_id: impl Into<String>, config: C, metadata: Option<Value>, ) -> Result<Trigger, IIIError>

Register a trigger with compile-time validated trigger config and optional metadata.

Source

impl<C, R> TriggerTypeRef<C, R>
where R: DeserializeOwned + JsonSchema + Send + 'static,

pub fn register_function<O, E, F>( &self, id: impl Into<String>, f: F, ) -> FunctionRef
where O: Serialize + JsonSchema + Send + 'static, E: Display + Send + 'static, F: Fn(R) -> Result<O, E> + Send + Sync + 'static,

Register a sync function whose input type must match the call request format R.

pub fn register_function_async<O, E, F, Fut>( &self, id: impl Into<String>, f: F, ) -> FunctionRef
where O: Serialize + JsonSchema + Send + 'static, E: Display + Send + 'static, F: Fn(R) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<O, E>> + Send + 'static,

Register an async function whose input type must match the call request format R.