Module structs

Module structs 

Structs

AuthInput
Input passed to the RBAC auth function during WebSocket upgrade.
AuthResult
Return value from the RBAC auth function.
MiddlewareFunctionInput
Input passed to the RBAC middleware function on every function invocation through the RBAC port.
OnFunctionRegistrationInput
Input passed to the on_function_registration_function_id hook when a worker attempts to register a function through the RBAC port. Return an OnFunctionRegistrationResult with the (possibly mapped) fields, or return an error to deny the registration.
OnFunctionRegistrationResult
Result returned from the on_function_registration_function_id hook. Omitted fields keep the original value from the registration request.
OnTriggerRegistrationInput
Input passed to the on_trigger_registration_function_id hook when a worker attempts to register a trigger through the RBAC port. Return an OnTriggerRegistrationResult with the (possibly mapped) fields, or return an error to deny the registration.
OnTriggerRegistrationResult
Result returned from the on_trigger_registration_function_id hook. Omitted fields keep the original value from the registration request.
OnTriggerTypeRegistrationInput
Input passed to the on_trigger_type_registration_function_id hook when a worker attempts to register a new trigger type through the RBAC port. Return an OnTriggerTypeRegistrationResult with the (possibly mapped) fields, or return an error to deny the registration.
OnTriggerTypeRegistrationResult
Result returned from the on_trigger_type_registration_function_id hook. Omitted fields keep the original value from the registration request.