pub struct OnFunctionRegistrationInput {
pub function_id: String,
pub description: Option<String>,
pub metadata: Option<Value>,
pub context: Value,
}Expand description
Input passed to the on_function_registration_function_id hook
when a worker attempts to register a function through the RBAC port.
Return an OnFunctionRegistrationResult with the (possibly mapped)
fields, or return an error to deny the registration.
Fields
function_id: StringID of the function being registered.
description: Option<String>Human-readable description of the function.
metadata: Option<Value>Arbitrary metadata attached to the function.
context: ValueAuth context from AuthResult.context for this session.