pub struct OnTriggerTypeRegistrationInput {
pub trigger_type_id: String,
pub description: String,
pub context: Value,
}Expand description
Input passed to the on_trigger_type_registration_function_id hook
when a worker attempts to register a new trigger type through the RBAC port.
Return an OnTriggerTypeRegistrationResult with the (possibly mapped)
fields, or return an error to deny the registration.
Fields
trigger_type_id: StringID of the trigger type being registered.
description: StringHuman-readable description of the trigger type.
context: ValueAuth context from AuthResult.context for this session.