Re-exports
pub use error::Error;pub use error::InvocationError;pub use iii::TelemetryOptions;pub use iii::IIIClient;pub use iii::RegisterFunction;pub use iii::RegisterTriggerType;pub use protocol::Message;pub use protocol::TriggerAction;pub use stream_provider::IStream;pub use structs::MiddlewareFunctionInput;pub use types::StreamRequest;pub use types::StreamResponse;
Modules
- builtin_
triggers - channel
- Public channel types. (Stage 1 submodule grouping.)
- channels
- engine
- Engine function and trigger ids, mirroring the Node SDK constants.
- error
- errors
- Public error types. (Stage 1 submodule grouping.)
- helpers
- Helper free functions that operate on an
IIIClientinstance. - iii
- protocol
- runtime
- Public runtime/worker types. (Stage 1 submodule grouping.)
- stream_
provider - structs
- trigger
- Public trigger types. (Stage 1 submodule grouping.)
- triggers
- types
Structs
- Enqueue
Result - Result returned by the engine when a message is successfully enqueued.
- Init
Options - Configuration options passed to
register_worker.
Functions
- register_
worker - Create and return a connected SDK instance. The WebSocket connection is established automatically in a dedicated background thread with its own tokio runtime.